==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/id-ID/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'Tentang Lokasi',
    'about_locations'           => 'Lokasi digunakan untuk melacak informasi lokasi bagi pengguna, aset, dan item lainnya',
    'assets_rtd'                => 'Aset', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Aset-aset yang ditetapkan',
    'id'                        => 'ID',
    'city'                      => 'Kota',
    'state'                     => 'Provinsi',
    'country'                   => 'Negara',
    'create'                    => 'Membuat Lokasi',
    'update'                    => 'Perbarui Lokasi',
    'print_assigned'            => 'Cetak Semua Ditugaskan',
    'print_all_assigned'        => 'Cetak Semua Ditugaskan',
    'name'                      => 'Nama lokasi',
    'address'                   => 'Alamat',
    'address2'                   => 'Baris Alamat 2',
    'zip'                       => 'Kode Pos',
    'locations'                 => 'Lokasi',
    'parent'                    => 'Induk',
    'currency'                  => 'Lokasi Mata Uang',
    'ldap_ou'                   => 'LDAP Cari OU',
    'user_name'                 => 'Nama Pengguna',
    'department'                => 'Departemen',
    'location'                  => 'Lokasi',
    'asset_tag'                 => 'Kode Aset',
    'asset_name'                => 'Nama',
    'asset_category'            => 'Kategori',
    'asset_manufacturer'        => 'Pabrikan',
    'asset_model'               => 'Model',
    'asset_serial'              => 'Serial',
    'asset_location'            => 'Lokasi',
    'asset_checked_out'         => 'Dipakai',
    'asset_expected_checkin'    => 'Tanggal Pengembalian',
    'date'                      => 'Tanggal:',
    'phone'                     => 'Location Phone',
    'signed_by_asset_auditor'   => 'Ditandatangani Oleh (Aset Auditor):',
    'signed_by_finance_auditor' => 'Ditandatangani Oleh (Auditor Keuangan):',
    'signed_by_location_manager' => 'Ditandatangani Oleh (Penanggung Jawab):',
    'signed_by'                 => 'Ditandatangani Oleh:',
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/id-ID/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'Tentang Lokasi',
    'about_locations'           => 'Lokasi digunakan untuk melacak informasi lokasi bagi pengguna, aset, dan item lainnya',
    'assets_rtd'                => 'Aset', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Aset-aset yang ditetapkan',
    'id'                        => 'ID',
    'city'                      => 'Kota',
    'state'                     => 'Provinsi',
    'country'                   => 'Negara',
    'create'                    => 'Membuat Lokasi',
    'update'                    => 'Perbarui Lokasi',
    'print_assigned'            => 'Cetak Semua Ditugaskan',
    'print_all_assigned'        => 'Cetak Semua Ditugaskan',
    'name'                      => 'Nama lokasi',
    'address'                   => 'Alamat',
    'address2'                   => 'Baris Alamat 2',
    'zip'                       => 'Kode Pos',
    'locations'                 => 'Lokasi',
    'parent'                    => 'Induk',
    'currency'                  => 'Lokasi Mata Uang',
    'ldap_ou'                   => 'LDAP Cari OU',
    'user_name'                 => 'Nama Pengguna',
    'department'                => 'Departemen',
    'location'                  => 'Lokasi',
    'asset_tag'                 => 'Kode Aset',
    'asset_name'                => 'Nama',
    'asset_category'            => 'Kategori',
    'asset_manufacturer'        => 'Pabrikan',
    'asset_model'               => 'Model',
    'asset_serial'              => 'Serial',
    'asset_location'            => 'Lokasi',
    'asset_checked_out'         => 'Dipakai',
    'asset_expected_checkin'    => 'Tanggal Pengembalian',
    'date'                      => 'Tanggal:',
    'phone'                     => 'Nomor Telepon Lokasi',
    'signed_by_asset_auditor'   => 'Ditandatangani Oleh (Aset Auditor):',
    'signed_by_finance_auditor' => 'Ditandatangani Oleh (Auditor Keuangan):',
    'signed_by_location_manager' => 'Ditandatangani Oleh (Penanggung Jawab):',
    'signed_by'                 => 'Ditandatangani Oleh:',
];
